(build-animated-gif delay repeat frames)Build an animated gives and return the corresponding bytes array. Delay: delay in milliseconds between each frame Repeat: number of times the gif should repeat (0 means forever) Frames: sequence of frames, as BufferedImage
Build an animated gives and return the corresponding bytes array. Delay: delay in milliseconds between each frame Repeat: number of times the gif should repeat (0 means forever) Frames: sequence of frames, as BufferedImage
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |